import React from 'react';
import PropTypes from 'prop-types';
import parser from 'html-react-parser';
import sanitizeHtml from 'sanitize-html';

const pattern = /([^\n]\n)(?=[^\n])/g;
const keyPrefix = 'paragraph';

function splitParagraphs(text) {
  return text.replace(/\r\n?/g, '\n').split(/\n\n+/).map(t => (
    pattern.test(t) ? t.replace(pattern, '$1<br/>') : t
  ));
}

export default function SimpleFormat({ text, wrapperTag, prefix, postfix, ...props }) {
  const sanitizedText = text ? sanitizeHtml(text) : '';
  const paragraphs = splitParagraphs(sanitizedText);
  const length = paragraphs.length;

  const children = paragraphs.map((p, i) => {
    let element = parser(p);

    if (!Array.isArray(element)) element = [element];

    if (i === 0 && prefix) element = [prefix, ...element];
    if (i === length - 1 && postfix) element = [...element, postfix];

    return React.createElement(wrapperTag, { key: `${keyPrefix}-${i}`, ...props }, element);
  });
  return React.createElement('div', {}, children);
}

SimpleFormat.propTypes = {
  text: PropTypes.string,
  wrapperTag: PropTypes.string,
  prefix: PropTypes.node,
  postfix: PropTypes.node,
};

SimpleFormat.defaultProps = {
  wrapperTag: 'p',
};
